@@ -3,7 +3,7 @@ package Digest::MD5;
 use strict;
 use vars qw($VERSION @ISA @EXPORT_OK);
 
-$VERSION = '2.29';  # $Date: 2003/10/06 17:32:18 $
+$VERSION = '2.32';  # $Date: 2003/12/05 10:11:49 $
 
 require Exporter;
 *import = \&Exporter::import;
@@ -12,6 +12,16 @@ require Exporter;
 require DynaLoader;
 @ISA=qw(DynaLoader);
 
+eval {
+    require Digest::base;
+    push(@ISA, 'Digest::base');
+};
+if ($@) {
+    my $err = $@;
+    *add_bits = sub { die $err };
+}
+
+
 eval {
     Digest::MD5->bootstrap($VERSION);
 };
@@ -173,6 +183,16 @@ or reset the $md5 object if this occurs.
 In most cases you want to make sure that the $io_handle is in
 C<binmode> before you pass it as argument to the addfile() method.
 
+=item $md5->add_bits($data, $nbits)
+
+=item $md5->add_bits($bitstring)
+
+Since the MD5 algorithm is byte oriented you might only add bits as
+multiples of 8, so you probably want to just use add() instead.  The
+add_bits() method is provided for compatibility with other digest
+implementations.  See L<Digest> for description of the arguments
+that add_bits() take.
+
 =item $md5->digest
 
 Return the binary digest for the message.  The returned string will be
